==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/DelegateBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DelegateBuilder extends DelegateFluentImpl<DelegateBuilder> implements VisitableBuilder<Delegate,DelegateBuilder>{
  public DelegateBuilder() {
    this(false);
  }
  public DelegateBuilder(Boolean validationEnabled) {
    this(new Delegate(), validationEnabled);
  }
  public DelegateBuilder(DelegateFluent<?> fluent) {
    this(fluent, false);
  }
  public DelegateBuilder(DelegateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Delegate(), validationEnabled);
  }
  public DelegateBuilder(DelegateFluent<?> fluent,Delegate instance) {
    this(fluent, instance, false);
  }
  public DelegateBuilder(DelegateFluent<?> fluent,Delegate instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withNamespace(instance.getNamespace());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DelegateBuilder(Delegate instance) {
    this(instance,false);
  }
  public DelegateBuilder(Delegate instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
    }
    this.validationEnabled = validationEnabled; 
  }
  DelegateFluent<?> fluent;
  Boolean validationEnabled;
  public Delegate build() {
    Delegate buildable = new Delegate(fluent.getName(),fluent.getNamespace());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/DelegateBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DelegateBuilder extends DelegateFluent<DelegateBuilder> implements VisitableBuilder<Delegate,DelegateBuilder>{
  public DelegateBuilder() {
    this(false);
  }
  public DelegateBuilder(Boolean validationEnabled) {
    this(new Delegate(), validationEnabled);
  }
  public DelegateBuilder(DelegateFluent<?> fluent) {
    this(fluent, false);
  }
  public DelegateBuilder(DelegateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Delegate(), validationEnabled);
  }
  public DelegateBuilder(DelegateFluent<?> fluent,Delegate instance) {
    this(fluent, instance, false);
  }
  public DelegateBuilder(DelegateFluent<?> fluent,Delegate instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Delegate());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withNamespace(instance.getNamespace());
      fluent.withName(instance.getName());
      fluent.withNamespace(instance.getNamespace());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DelegateBuilder(Delegate instance) {
    this(instance,false);
  }
  public DelegateBuilder(Delegate instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Delegate());

    if (instance != null) {
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
    }
    this.validationEnabled = validationEnabled; 
  }
  DelegateFluent<?> fluent;
  Boolean validationEnabled;
  public Delegate build() {
    Delegate buildable = new Delegate(fluent.getName(),fluent.getNamespace());
    return buildable;
  }
  
}
